==> kubernetes-model-core-5.1.1-sources.jar: io/fabric8/kubernetes/api/model/EventFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Object;
import java.util.Map;

public interface EventFluent<A extends EventFluent<A>> extends Fluent<A> {


    public String getAction();
    public A withAction(String action);
    public Boolean hasAction();
    public A withNewAction(String arg1);
    public A withNewAction(StringBuilder arg1);
    public A withNewAction(StringBuffer arg1);
    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public Integer getCount();
    public A withCount(Integer count);
    public Boolean hasCount();
    public A withNewCount(String arg1);
    public A withNewCount(int arg1);
    
/**
 * This method has been deprecated, please use method buildEventTime instead.
 * @return The buildable object.
 */
@Deprecated public MicroTime getEventTime();
    public MicroTime buildEventTime();
    public A withEventTime(MicroTime eventTime);
    public Boolean hasEventTime();
    public A withNewEventTime(String time);
    public EventFluent.EventTimeNested<A> withNewEventTime();
    public EventFluent.EventTimeNested<A> withNewEventTimeLike(MicroTime item);
    public EventFluent.EventTimeNested<A> editEventTime();
    public EventFluent.EventTimeNested<A> editOrNewEventTime();
    public EventFluent.EventTimeNested<A> editOrNewEventTimeLike(MicroTime item);
    public String getFirstTimestamp();
    public A withFirstTimestamp(String firstTimestamp);
    public Boolean hasFirstTimestamp();
    public A withNewFirstTimestamp(String arg1);
    public A withNewFirstTimestamp(StringBuilder arg1);
    public A withNewFirstTimestamp(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildInvolvedObject instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getInvolvedObject();
    public ObjectReference buildInvolvedObject();
    public A withInvolvedObject(ObjectReference involvedObject);
    public Boolean hasInvolvedObject();
    public EventFluent.InvolvedObjectNested<A> withNewInvolvedObject();
    public EventFluent.InvolvedObjectNested<A> withNewInvolvedObjectLike(ObjectReference item);
    public EventFluent.InvolvedObjectNested<A> editInvolvedObject();
    public EventFluent.InvolvedObjectNested<A> editOrNewInvolvedObject();
    public EventFluent.InvolvedObjectNested<A> editOrNewInvolvedObjectLike(ObjectReference item);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public String getLastTimestamp();
    public A withLastTimestamp(String lastTimestamp);
    public Boolean hasLastTimestamp();
    public A withNewLastTimestamp(String arg1);
    public A withNewLastTimestamp(StringBuilder arg1);
    public A withNewLastTimestamp(StringBuffer arg1);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(String arg1);
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public EventFluent.MetadataNested<A> withNewMetadata();
    public EventFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public EventFluent.MetadataNested<A> editMetadata();
    public EventFluent.MetadataNested<A> editOrNewMetadata();
    public EventFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(String arg1);
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildRelated instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getRelated();
    public ObjectReference buildRelated();
    public A withRelated(ObjectReference related);
    public Boolean hasRelated();
    public EventFluent.RelatedNested<A> withNewRelated();
    public EventFluent.RelatedNested<A> withNewRelatedLike(ObjectReference item);
    public EventFluent.RelatedNested<A> editRelated();
    public EventFluent.RelatedNested<A> editOrNewRelated();
    public EventFluent.RelatedNested<A> editOrNewRelatedLike(ObjectReference item);
    public String getReportingComponent();
    public A withReportingComponent(String reportingComponent);
    public Boolean hasReportingComponent();
    public A withNewReportingComponent(String arg1);
    public A withNewReportingComponent(StringBuilder arg1);
    public A withNewReportingComponent(StringBuffer arg1);
    public String getReportingInstance();
    public A withReportingInstance(String reportingInstance);
    public Boolean hasReportingInstance();
    public A withNewReportingInstance(String arg1);
    public A withNewReportingInstance(StringBuilder arg1);
    public A withNewReportingInstance(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSeries instead.
 * @return The buildable object.
 */
@Deprecated public EventSeries getSeries();
    public EventSeries buildSeries();
    public A withSeries(EventSeries series);
    public Boolean hasSeries();
    public EventFluent.SeriesNested<A> withNewSeries();
    public EventFluent.SeriesNested<A> withNewSeriesLike(EventSeries item);
    public EventFluent.SeriesNested<A> editSeries();
    public EventFluent.SeriesNested<A> editOrNewSeries();
    public EventFluent.SeriesNested<A> editOrNewSeriesLike(EventSeries item);
    
/**
 * This method has been deprecated, please use method buildSource instead.
 * @return The buildable object.
 */
@Deprecated public EventSource getSource();
    public EventSource buildSource();
    public A withSource(EventSource source);
    public Boolean hasSource();
    public A withNewSource(String component,String host);
    public EventFluent.SourceNested<A> withNewSource();
    public EventFluent.SourceNested<A> withNewSourceLike(EventSource item);
    public EventFluent.SourceNested<A> editSource();
    public EventFluent.SourceNested<A> editOrNewSource();
    public EventFluent.SourceNested<A> editOrNewSourceLike(EventSource item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);
    public interface EventTimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,MicroTimeFluent<EventFluent.EventTimeNested<N>> {

            public N and();
            public N endEventTime();    }


    public interface InvolvedObjectNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<EventFluent.InvolvedObjectNested<N>> {

            public N and();
            public N endInvolvedObject();    }


    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<EventFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface RelatedNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<EventFluent.RelatedNested<N>> {

            public N and();
            public N endRelated();    }


    public interface SeriesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EventSeriesFluent<EventFluent.SeriesNested<N>> {

            public N and();
            public N endSeries();    }


    public interface SourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EventSourceFluent<EventFluent.SourceNested<N>> {

            public N and();
            public N endSource();    }


}

==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/EventFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Object;
import java.util.Map;

public interface EventFluent<A extends EventFluent<A>> extends Fluent<A> {


    public String getAction();
    public A withAction(String action);
    public Boolean hasAction();
    public A withNewAction(StringBuilder arg1);
    public A withNewAction(int[] arg1,int arg2,int arg3);
    public A withNewAction(char[] arg1);
    public A withNewAction(StringBuffer arg1);
    public A withNewAction(byte[] arg1,int arg2);
    public A withNewAction(byte[] arg1);
    public A withNewAction(char[] arg1,int arg2,int arg3);
    public A withNewAction(byte[] arg1,int arg2,int arg3);
    public A withNewAction(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewAction(String arg1);
    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public Integer getCount();
    public A withCount(Integer count);
    public Boolean hasCount();
    public A withNewCount(int arg1);
    
/**
 * This method has been deprecated, please use method buildEventTime instead.
 * @return The buildable object.
 */
@Deprecated public MicroTime getEventTime();
    public MicroTime buildEventTime();
    public A withEventTime(MicroTime eventTime);
    public Boolean hasEventTime();
    public A withNewEventTime(String time);
    public EventFluent.EventTimeNested<A> withNewEventTime();
    public EventFluent.EventTimeNested<A> withNewEventTimeLike(MicroTime item);
    public EventFluent.EventTimeNested<A> editEventTime();
    public EventFluent.EventTimeNested<A> editOrNewEventTime();
    public EventFluent.EventTimeNested<A> editOrNewEventTimeLike(MicroTime item);
    public String getFirstTimestamp();
    public A withFirstTimestamp(String firstTimestamp);
    public Boolean hasFirstTimestamp();
    public A withNewFirstTimestamp(StringBuilder arg1);
    public A withNewFirstTimestamp(int[] arg1,int arg2,int arg3);
    public A withNewFirstTimestamp(char[] arg1);
    public A withNewFirstTimestamp(StringBuffer arg1);
    public A withNewFirstTimestamp(byte[] arg1,int arg2);
    public A withNewFirstTimestamp(byte[] arg1);
    public A withNewFirstTimestamp(char[] arg1,int arg2,int arg3);
    public A withNewFirstTimestamp(byte[] arg1,int arg2,int arg3);
    public A withNewFirstTimestamp(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFirstTimestamp(String arg1);
    
/**
 * This method has been deprecated, please use method buildInvolvedObject instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getInvolvedObject();
    public ObjectReference buildInvolvedObject();
    public A withInvolvedObject(ObjectReference involvedObject);
    public Boolean hasInvolvedObject();
    public EventFluent.InvolvedObjectNested<A> withNewInvolvedObject();
    public EventFluent.InvolvedObjectNested<A> withNewInvolvedObjectLike(ObjectReference item);
    public EventFluent.InvolvedObjectNested<A> editInvolvedObject();
    public EventFluent.InvolvedObjectNested<A> editOrNewInvolvedObject();
    public EventFluent.InvolvedObjectNested<A> editOrNewInvolvedObjectLike(ObjectReference item);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public String getLastTimestamp();
    public A withLastTimestamp(String lastTimestamp);
    public Boolean hasLastTimestamp();
    public A withNewLastTimestamp(StringBuilder arg1);
    public A withNewLastTimestamp(int[] arg1,int arg2,int arg3);
    public A withNewLastTimestamp(char[] arg1);
    public A withNewLastTimestamp(StringBuffer arg1);
    public A withNewLastTimestamp(byte[] arg1,int arg2);
    public A withNewLastTimestamp(byte[] arg1);
    public A withNewLastTimestamp(char[] arg1,int arg2,int arg3);
    public A withNewLastTimestamp(byte[] arg1,int arg2,int arg3);
    public A withNewLastTimestamp(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewLastTimestamp(String arg1);
    public String getMessage();
    public A withMessage(String message);
    public Boolean hasMessage();
    public A withNewMessage(StringBuilder arg1);
    public A withNewMessage(int[] arg1,int arg2,int arg3);
    public A withNewMessage(char[] arg1);
    public A withNewMessage(StringBuffer arg1);
    public A withNewMessage(byte[] arg1,int arg2);
    public A withNewMessage(byte[] arg1);
    public A withNewMessage(char[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3);
    public A withNewMessage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMessage(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public EventFluent.MetadataNested<A> withNewMetadata();
    public EventFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public EventFluent.MetadataNested<A> editMetadata();
    public EventFluent.MetadataNested<A> editOrNewMetadata();
    public EventFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(int[] arg1,int arg2,int arg3);
    public A withNewReason(char[] arg1);
    public A withNewReason(StringBuffer arg1);
    public A withNewReason(byte[] arg1,int arg2);
    public A withNewReason(byte[] arg1);
    public A withNewReason(char[] arg1,int arg2,int arg3);
    public A withNewReason(byte[] arg1,int arg2,int arg3);
    public A withNewReason(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewReason(String arg1);
    
/**
 * This method has been deprecated, please use method buildRelated instead.
 * @return The buildable object.
 */
@Deprecated public ObjectReference getRelated();
    public ObjectReference buildRelated();
    public A withRelated(ObjectReference related);
    public Boolean hasRelated();
    public EventFluent.RelatedNested<A> withNewRelated();
    public EventFluent.RelatedNested<A> withNewRelatedLike(ObjectReference item);
    public EventFluent.RelatedNested<A> editRelated();
    public EventFluent.RelatedNested<A> editOrNewRelated();
    public EventFluent.RelatedNested<A> editOrNewRelatedLike(ObjectReference item);
    public String getReportingComponent();
    public A withReportingComponent(String reportingComponent);
    public Boolean hasReportingComponent();
    public A withNewReportingComponent(StringBuilder arg1);
    public A withNewReportingComponent(int[] arg1,int arg2,int arg3);
    public A withNewReportingComponent(char[] arg1);
    public A withNewReportingComponent(StringBuffer arg1);
    public A withNewReportingComponent(byte[] arg1,int arg2);
    public A withNewReportingComponent(byte[] arg1);
    public A withNewReportingComponent(char[] arg1,int arg2,int arg3);
    public A withNewReportingComponent(byte[] arg1,int arg2,int arg3);
    public A withNewReportingComponent(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewReportingComponent(String arg1);
    public String getReportingInstance();
    public A withReportingInstance(String reportingInstance);
    public Boolean hasReportingInstance();
    public A withNewReportingInstance(StringBuilder arg1);
    public A withNewReportingInstance(int[] arg1,int arg2,int arg3);
    public A withNewReportingInstance(char[] arg1);
    public A withNewReportingInstance(StringBuffer arg1);
    public A withNewReportingInstance(byte[] arg1,int arg2);
    public A withNewReportingInstance(byte[] arg1);
    public A withNewReportingInstance(char[] arg1,int arg2,int arg3);
    public A withNewReportingInstance(byte[] arg1,int arg2,int arg3);
    public A withNewReportingInstance(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewReportingInstance(String arg1);
    
/**
 * This method has been deprecated, please use method buildSeries instead.
 * @return The buildable object.
 */
@Deprecated public EventSeries getSeries();
    public EventSeries buildSeries();
    public A withSeries(EventSeries series);
    public Boolean hasSeries();
    public EventFluent.SeriesNested<A> withNewSeries();
    public EventFluent.SeriesNested<A> withNewSeriesLike(EventSeries item);
    public EventFluent.SeriesNested<A> editSeries();
    public EventFluent.SeriesNested<A> editOrNewSeries();
    public EventFluent.SeriesNested<A> editOrNewSeriesLike(EventSeries item);
    
/**
 * This method has been deprecated, please use method buildSource instead.
 * @return The buildable object.
 */
@Deprecated public EventSource getSource();
    public EventSource buildSource();
    public A withSource(EventSource source);
    public Boolean hasSource();
    public A withNewSource(String component,String host);
    public EventFluent.SourceNested<A> withNewSource();
    public EventFluent.SourceNested<A> withNewSourceLike(EventSource item);
    public EventFluent.SourceNested<A> editSource();
    public EventFluent.SourceNested<A> editOrNewSource();
    public EventFluent.SourceNested<A> editOrNewSourceLike(EventSource item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(StringBuilder arg1);
    public A withNewType(int[] arg1,int arg2,int arg3);
    public A withNewType(char[] arg1);
    public A withNewType(StringBuffer arg1);
    public A withNewType(byte[] arg1,int arg2);
    public A withNewType(byte[] arg1);
    public A withNewType(char[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewType(String arg1);
    public interface EventTimeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,MicroTimeFluent<EventFluent.EventTimeNested<N>> {

            public N and();
            public N endEventTime();    }


    public interface InvolvedObjectNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<EventFluent.InvolvedObjectNested<N>> {

            public N and();
            public N endInvolvedObject();    }


    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<EventFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface RelatedNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectReferenceFluent<EventFluent.RelatedNested<N>> {

            public N and();
            public N endRelated();    }


    public interface SeriesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EventSeriesFluent<EventFluent.SeriesNested<N>> {

            public N and();
            public N endSeries();    }


    public interface SourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EventSourceFluent<EventFluent.SourceNested<N>> {

            public N and();
            public N endSource();    }


}
